def cypb(current_index, events, cyname=""):
    bar_length = 50

    # 检查传入的参数类型
    if isinstance(events, int):  # 如果是整数，认为是处理单个数字的情况
        total_events = events
    else:  # 否则，假设传入的是事件列表
        total_events = len(events)

    progress = (current_index + 1) / total_events
    block = int(round(bar_length * progress))
    progress_bar = str(cyname) + "|" + "█" * block + " " * (bar_length - block) + "|"

    if progress == 1:
        print(f"\r{progress_bar} {progress * 100:.2f}% ({current_index + 1}/{total_events})\n", end="", flush=True)
    else:
        print(f"\r{progress_bar} {progress * 100:.2f}% ({current_index + 1}/{total_events})", end="", flush=True)


import datetime
from colorama import Fore, Style, init

init(autoreset=True)  # 初始化colorama库

class LogColors:
    INFO = Fore.WHITE
    WARNING = Fore.YELLOW
    SUCCESS = Fore.RED
    ERROR = Fore.CYAN
    DEBUG = Fore.BLUE

def cyprint(message, level='info'):
    levels = {'info': LogColors.INFO, 'warning': LogColors.WARNING, 'success': LogColors.SUCCESS, 'error': LogColors.ERROR, 'debug': LogColors.DEBUG}
    colors = {'WHITE': 'info', 'YELLOW': 'warning', 'RED': 'success', 'CYAN': 'error', 'BLUE': 'debug'}

    level_lower = level.lower()
    if level_lower not in levels:
        if level.upper() in colors:
            level_lower = colors[level.upper()]
            colored_level = levels[level_lower] + level_lower.upper() + Style.RESET_ALL
        else:
            level_lower = "info"
            level_upper = level.upper()

            # 使用 getattr() 动态获取颜色属性
            fore_color = getattr(Fore, level_upper)
            colored_level = fore_color + level_lower.upper() + Style.RESET_ALL
    else:
        colored_level = levels[level_lower] + level_lower.upper() + Style.RESET_ALL
    current_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    log_entry = f'{Fore.GREEN}[{current_time}]{Style.RESET_ALL}  {colored_level}  {message}'
    print(log_entry)



# cyprint('测试', 'MAGENTA')
# cyprint('测试', 'info')
# cyprint('警告信息', "WARNING")
# cyprint('成功信息', "SUCCESS")
# cyprint('错误信息', "ERROR")
# cyprint('debug信息', "DEBUG")


from setuptools import setup, find_packages

setup(
    name='cyprint',
    version='1.0.7',
    packages=find_packages(),
    description='Customized colorful logging in Python',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author='xciny',
    author_email='229735037@qq.com',
    url='https://pypi.org/manage/project/cyprint',
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[
        'colorama',  # Add your dependencies here
    ],
)
